<template>
  <el-dialog title="选择物资信息" :visible.sync="showDia" append-to-body :close-on-click-modal="false" width="80%"
    :show-close="true" :before-close="handleClose" top="5vh">
    <div class="tree-table-container">
      <el-row class="fullheight">
        <el-col :span="4" class="fullheight">
          <div class="common-tree-container">
            <div class="common-tree-title">
              <i class="el-icon-menu" /> 物资分类目录
            </div>
            <div class="common-tree-content">
              <el-tree v-if="treeData.length" highlight-current :data="treeData" :props="defaultProps"
                default-expand-all @node-click="handleNodeClick" />
            </div>
          </div>
        </el-col>
        <el-col :span="20" class="fullheight">
          <div class="common-table-container">
            <div class="bbsl-common-page">
              <div class="bbsl-table-search">
                <el-form v-model="queryParam" :inline="true">
                  <el-row :gutter="5">
                    <el-col :span="7">
                      <el-form-item label="品名">
                        <el-input v-model="querys[0].value" clearable placeholder="请输入品名" />
                      </el-form-item>
                    </el-col>
                    <el-col :span="6">
                      <el-form-item>
                        <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
                        </el-button>
                        <el-button icon="el-icon-refresh" @click="handleReset">重置
                        </el-button>
                      </el-form-item>
                    </el-col>
                    <span v-if="textShow" style="float:right;color:red">数量为零的不可以领用</span>
                  </el-row>
                </el-form>
              </div>
              <div ref="contentPanel" class="bbsl-table-content">
                <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData" :height="360"
                  :style="{ width: '100%' }" :cell-style="{ 'text-align': 'center' }"
                  :header-cell-style="{ 'text-align': 'center' }" @selection-change="handleSelectChange"
                  @cell-click="editCell" :row-key="getRowKey">
                  <el-table-column type="selection" width="55" :reserve-selection="true"
                    :selectable="checkSelectable" />
                  <el-table-column type="index" width="55" label="序号" />
                  <el-table-column prop="name" label="品名" show-overflow-tooltip />
                  <el-table-column prop="code" label="编号" show-overflow-tooltip />
                  <el-table-column prop="model" label="型号" show-overflow-tooltip />
                  <el-table-column prop="unit" label="单位" show-overflow-tooltip />
                  <el-table-column prop="price" label="单价" show-overflow-tooltip />
                  <el-table-column prop="quantity" label="数量" show-overflow-tooltip />
                  <!-- <el-table-column label="单价" width="150" prop="price">
                    <template slot-scope="scope">
                      <el-input v-model="scope.row.price" size="mini" />
                    </template>
<template slot-scope="scope">
                      <span v-if="!isEdit">{{ scope.row.price }}</span>
                      <el-input
                        v-if="isEdit"
                        v-model="scope.row.price"
                        size="mini"
                      />
                    </template>
</el-table-column>
<el-table-column label="数量" width="150" prop="num">
  <template slot-scope="scope">
                      <el-input v-model="scope.row.num" size="mini" />
                    </template>
  <template slot-scope="scope">
                      <span v-if="!isEdit">{{ scope.row.num }}</span>
                      <el-input
                        v-if="isEdit"
                        v-model="scope.row.num"
                        size="mini"
                      />
                    </template>
</el-table-column> -->
                </el-table>
                <el-pagination ref="paginationPanel" align="right" background :current-page="queryParam.pageBean.page"
                  :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
                  layout="total, sizes, prev, pager, next, jumper" :total="total" @size-change="handleSizeChange"
                  @current-change="handleCurrentChange" />
              </div>
            </div>
          </div>
        </el-col>
      </el-row>
    </div>
    <div slot="footer" class="dialog-footer">
      <el-button type="primary" @click="saveMaterial">确认添加</el-button>
      <el-button type="infor" @click="handleClose">取 消</el-button>
    </div>
  </el-dialog>
</template>

<script>
import classManage from '@/api/manager/material/materialInfoManage.js'
import { TableMixin } from '@/mixins/tableMixin'

export default {
  name: 'SelectMaterialDialog',
  components: {},
  mixins: [TableMixin],
  props: {
    // pageName: String,
    purchasingDetailList: {
      type: Array,
      default: function () {
        return []
      }
    },
    type: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      titles: '',
      tableData: [],
      showDia: false,
      isEdit: false,
      treeData: [
        { code: '0', id: 0, name: '物资分类信息', parentId: 0, children: [] }
      ],
      defaultProps: {
        value: 'id',
        label: 'name',
        parentId: 'parentId',
        code: 'code',
        children: 'children'
      },
      data: [],
      treeNode: {
        code: '0',
        id: 0,
        name: '物资分类信息',
        parentId: 0,
        children: []
      },
      updateTreeNode: null,
      url: {},
      materialSelection: [],
      sorter: [
        {
          direction: 'ASC',
          property: 'sn_'
        }
      ],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'warehouse_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'manufacturer_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'class_Id_',
          relation: 'AND',
          value: ''
        }
      ],
      textShow: true
    }
  },
  created() {
  },
  mounted() {
    this.getTreen()
  },
  methods: {
    // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    selectionEcho() {

      this.$nextTick(function () {
        this.purchasingDetailList.forEach(key => {
          this.tableData.forEach(row => {
            console.log(row);

            console.log(row.id == key)
            if (row.id == key.materialId) {
              this.$refs.multipleSelection.toggleRowSelection(row, true)
            }
            if (row.id == key.id) {
              this.$refs.multipleSelection.toggleRowSelection(row, true)
            }
          })
        })
      })
    },
    // 树查询
    getTreen() {
      classManage.loadAllClass({}, res => {
        // console.log(res)
        this.treeData[0].children = res.value
        this.$set(this.treeData)
      })
    },
    reload() {
      this.treeData = [
        { code: '', id: 0, name: '物资管理', parentId: 0, children: [] }
      ]
      this.$set(this.treeData)
      this.getTreen()
      this.loadData()
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 分页查询物资信息
    loadData(page) {
      // console.log(this.pageName)
      // let method = 'sdfs'
      // if (this.pageName == '领用申请') {
      //   // 新增
      //   method = classManage.materialInfoPageQuery
      // }
      // if (this.pageName == '采购需求申请') {
      //   // 修改
      //   method = classManage.materialInfoQuery
      // }
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      // this.queryParam.sorter = this.sorter
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      classManage.materialInfoPageQuery(this.queryParam).then(res => {
        console.log(res)
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
        this.selectionEcho()
      })
    },
    handleNodeClick(data) {
      // 点击分类树节点
      this.treeNode = data
      if (data.id == '0') {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      } else {
        this.querys[3].value = this.treeNode.id
        this.loadData(1)
      }
    },
    checkSelectable(val) {
      if (this.type === '采购申请') {
        return true
      } else {
        if (val.quantity == '0') {
          //禁用不可选行
          return false
        } else {
          return true
        }
      }

    },
    handleSelectChange(val) {
      this.materialSelection = val
    },
    handleClose() {
      this.materialSelection = []
      this.$refs.multipleSelection.clearSelection()
      // done()
      this.textShow = true
      this.showDia = false
    },
    saveMaterial() {
      // 获取选中数据
      var materials = []
      this.materialSelection.forEach(r => {
        let find = this.purchasingDetailList.find(item => item.materialId === r.id)
        materials.push({
          materialId: find ? find.materialId : r.id,
          remainingQuantity: r.quantity,
          quantity: find ? find.quantity : '',
          actualQuantity: find ? find.actualQuantity : '',
          sn: r.sn,
          name: r.name,
          model: r.model,
          memo: r.memo,
          id: find ? find.id : '',
          price: r.price,
          // amount: r.num * r.price,
          warehouseInoutId: null,
          // materialInfoId: r.id,
          materialInfoId: r.id,
          supplier: r.supplier,
          unit: r.unit,
          description: ''
        })
      })
      console.log(materials)
      this.$emit('saveSelectMaterial', materials)
      this.$refs.multipleSelection.clearSelection()

      // this.showDia = false
    },
    editCell() {
      this.isEdit = true
    },
    editCellCancel() {
      this.isEdit = false
    }
  }
}
</script>
<style lang="scss" scoped>
.common-tree-container ::v-deep .el-tree {
  border: none;
}
</style>
